@@ -15,24 +15,24 @@
 // specific language governing permissions and limitations
 // under the License.
 
-#define ARROW_VERSION_MAJOR 15
+#define ARROW_VERSION_MAJOR 16
 #define ARROW_VERSION_MINOR 0
-#define ARROW_VERSION_PATCH 2
+#define ARROW_VERSION_PATCH 0
 #define ARROW_VERSION ((ARROW_VERSION_MAJOR * 1000) + ARROW_VERSION_MINOR) * 1000 + ARROW_VERSION_PATCH
 
-#define ARROW_VERSION_STRING "15.0.2"
+#define ARROW_VERSION_STRING "16.0.0"
 
-#define ARROW_SO_VERSION "1500"
-#define ARROW_FULL_SO_VERSION "1500.2.0"
+#define ARROW_SO_VERSION "1600"
+#define ARROW_FULL_SO_VERSION "1600.0.0"
 
 #define ARROW_CXX_COMPILER_ID "Clang"
-#define ARROW_CXX_COMPILER_VERSION "18.1.2"
+#define ARROW_CXX_COMPILER_VERSION "18.1.4"
 #define ARROW_CXX_COMPILER_FLAGS "-O2 -pipe -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong -Qunused-arguments -fcolor-diagnostics"
 
 #define ARROW_BUILD_TYPE "RELEASE"
 
-#define ARROW_GIT_ID "9109a190a35ab3682b8f07dedd74811bff6da38e"
-#define ARROW_GIT_DESCRIPTION "srcinfo-cache-18846-g9109a190a"
+#define ARROW_GIT_ID "07d61d74e896c52aa53cb2a50caabd9ee4bc0e8f"
+#define ARROW_GIT_DESCRIPTION "srcinfo-cache-19477-g07d61d74e"
 
 #define ARROW_PACKAGE_KIND "mingw-w64-clang-aarch64"
 
@@ -47,15 +47,27 @@
 /* #undef ARROW_JEMALLOC */
 /* #undef ARROW_JEMALLOC_VENDORED */
 #define ARROW_JSON
+/* #undef ARROW_MIMALLOC */
 /* #undef ARROW_ORC */
 #define ARROW_PARQUET
 /* #undef ARROW_SUBSTRAIT */
 
+/* #undef ARROW_AZURE */
 #define ARROW_ENABLE_THREADING
 /* #undef ARROW_GCS */
+#define ARROW_HDFS
 #define ARROW_S3
+/* #undef ARROW_USE_GLOG */
 #define ARROW_USE_NATIVE_INT128
+#define ARROW_WITH_BROTLI
+#define ARROW_WITH_BZ2
+#define ARROW_WITH_LZ4
 /* #undef ARROW_WITH_MUSL */
 /* #undef ARROW_WITH_OPENTELEMETRY */
+#define ARROW_WITH_RE2
+#define ARROW_WITH_SNAPPY
 /* #undef ARROW_WITH_UCX */
+#define ARROW_WITH_UTF8PROC
+#define ARROW_WITH_ZLIB
+#define ARROW_WITH_ZSTD
 #define PARQUET_REQUIRE_ENCRYPTION
